==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Seu Nome");
define("_OK","Ok!");
define("_COMMENT","comentrio");
define("_CONFIGURE","Configurar");
define("_LOGINCREATE","Login/Criar uma Conta");
define("_THRESHOLD","Comeo");
define("_NOCOMMENTS","Sem Comentrios");
define("_NESTED","Alojados");
define("_FLAT","Plano");
define("_THREAD","Discusso");
define("_OLDEST","Velho Primeiro");
define("_NEWEST","Novo Primeiro");
define("_HIGHEST","Pontuao Alta Primeiro");
define("_COMMENTSWARNING","Os comentrios so propriedade de quem os escreveu. Ns no somos responsveis por seu contedo.");
define("_SCORE","Pontos:");
define("_USERINFO","Informaes do Usurios");
define("_READREST","Ler o resto deste comentrio...");
define("_REPLY","Responder a Este");
define("_REPLYMAIN","Enviar Comentrio");
define("_NOSUBJECT","Sem Ttulo");
define("_NOANONCOMMENTS","Comentrios no podem ser enviados por usurios annimos por favor <a href=\"modules.php?name=Your_Account\">registre-se</a>");
define("_PARENT","Pai");
define("_ROOT","Raiz");
define("_UCOMMENT","Comentrio");
define("_ALLOWEDHTML","HTML Permitido:");
define("_POSTANON","Enviar como Annimo");
define("_EXTRANS","Usar (comandos de HTML no texto)");
define("_HTMLFORMATED","Formatado em HTML");
define("_PLAINTEXT","Texto Puro");
define("_ONN","em...");
define("_SUBJECT","Ttulo");
define("_SURVEYCOM","Revisar Comentrio antes de envia-lo");
define("_SURVEYCOMPRE","Visualizar a reviso do comentrio");
define("_NOTRIGHT","Algo est errado se passar est varivel. Est mensagem possui apenas pensamentos para serem publicados em uma rodovia.");
define("_DIRECTCOM","Comentrio Revisto Diretamente...");
define("_SENDAMSG","Enviar a Mensagem");
define("_PASTSURVEYS","Pesquisas Anteriores");



define("_LVOTES","votos");
define("_TOTALVOTES","Total de Votos:");
define("_VOTING","Sala de Votao");
define("_OTHERPOLLS","Outras Pesquisas");
define("_CURRENTSURVEY","Pesquisa Atual");
define("_CURRENTPOLLRESULTS","Resultado Atual da Pesquisa");
define("_PREVIEW","Pr-Visualizao");
define("_REFRESH","Atualizar");
define("_SURVEYS","Pesquisas");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Seu Nome");
define("_OK","Ok!");
define("_COMMENT","comentrio");
define("_CONFIGURE","Configurar");
define("_LOGINCREATE","Login/Criar uma Conta");
define("_THRESHOLD","Comeo");
define("_NOCOMMENTS","Sem Comentrios");
define("_NESTED","Alojados");
define("_FLAT","Plano");
define("_THREAD","Discusso");
define("_OLDEST","Velho Primeiro");
define("_NEWEST","Novo Primeiro");
define("_HIGHEST","Pontuao Alta Primeiro");
define("_COMMENTSWARNING","Os comentrios so propriedade de quem os escreveu. Ns no somos responsveis por seu contedo.");
define("_SCORE","Pontos:");
define("_USERINFO","Informaes do Usurios");
define("_READREST","Ler o resto deste comentrio...");
define("_REPLY","Responder a Este");
define("_REPLYMAIN","Enviar Comentrio");
define("_NOSUBJECT","Sem Ttulo");
define("_NOANONCOMMENTS","Comentrios no podem ser enviados por usurios annimos por favor <a href=\"modules.php?name=Your_Account\">registre-se</a>");
define("_PARENT","Pai");
define("_ROOT","Raiz");
define("_UCOMMENT","Comentrio");
define("_ALLOWEDHTML","HTML Permitido:");
define("_POSTANON","Enviar como Annimo");
define("_EXTRANS","Usar (comandos de HTML no texto)");
define("_HTMLFORMATED","Formatado em HTML");
define("_PLAINTEXT","Texto Puro");
define("_ONN","em...");
define("_SUBJECT","Ttulo");
define("_SURVEYCOM","Revisar Comentrio antes de envia-lo");
define("_SURVEYCOMPRE","Visualizar a reviso do comentrio");
define("_NOTRIGHT","Algo est errado se passar est varivel. Est mensagem possui apenas pensamentos para serem publicados em uma rodovia.");
define("_DIRECTCOM","Comentrio Revisto Diretamente...");
define("_SENDAMSG","Enviar a Mensagem");
define("_PASTSURVEYS","Pesquisas Anteriores");



define("_LVOTES","votos");
define("_TOTALVOTES","Total de Votos:");
define("_VOTING","Sala de Votao");
define("_OTHERPOLLS","Outras Pesquisas");
define("_CURRENTSURVEY","Pesquisa Atual");
define("_CURRENTPOLLRESULTS","Resultado Atual da Pesquisa");
define("_PREVIEW","Pr-Visualizao");
define("_REFRESH","Atualizar");
define("_SURVEYS","Pesquisas");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
